@@ -1,6 +1,8 @@
 # --
 # Kernel/Output/HTML/PreferencesCustomQueue.pm
-# Copyright (C) 2001-2015 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2012 OTRS AG, http://otrs.org/
+# --
+# $Id: PreferencesCustomQueue.pm,v 1.17 2012/04/05 19:22:39 mb Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -12,14 +14,10 @@ package Kernel::Output::HTML::PreferencesCustomQueue;
 use strict;
 use warnings;
 
-our @ObjectDependencies = (
-    'Kernel::Output::HTML::Layout',
-    'Kernel::System::Cache',
-    'Kernel::System::DB',
-    'Kernel::System::Group',
-    'Kernel::System::Queue',
-    'Kernel::System::Web::Request',
-);
+use Kernel::System::CacheInternal;
+
+use vars qw($VERSION);
+$VERSION = qw($Revision: 1.17 $) [1];
 
 sub new {
     my ( $Type, %Param ) = @_;
@@ -28,10 +26,18 @@ sub new {
     my $Self = {%Param};
     bless( $Self, $Type );
 
-    for (qw(UserID ConfigItem)) {
+    # get needed objects
+    for (qw(ConfigObject LogObject DBObject LayoutObject UserID ParamObject QueueObject ConfigItem))
+    {
         die "Got no $_!" if ( !$Self->{$_} );
     }
 
+    $Self->{CacheInternalObject} = Kernel::System::CacheInternal->new(
+        %{$Self},
+        Type => 'Queue',
+        TTL  => 60 * 60 * 24 * 20,
+    );
+
     return $Self;
 }
 
@@ -45,20 +51,18 @@ sub Param {
     # check needed param, if no user id is given, do not show this box
     if ( !$Param{UserData}->{UserID} ) {
         return ();
-
     }
-    my $QueueObject = $Kernel::OM->Get('Kernel::System::Queue');
     if ( $Param{UserData}->{UserID} ) {
-        %QueueData = $QueueObject->GetAllQueues(
+        %QueueData = $Self->{QueueObject}->GetAllQueues(
             UserID => $Param{UserData}->{UserID},
-            Type   => $Self->{ConfigItem}->{Permission} || 'ro',
+            Type => $Self->{ConfigItem}->{Permission} || 'ro',
         );
     }
-    if ( $Kernel::OM->Get('Kernel::System::Web::Request')->GetArray( Param => 'QueueID' ) ) {
-        @CustomQueueIDs = $Kernel::OM->Get('Kernel::System::Web::Request')->GetArray( Param => 'QueueID' );
+    if ( $Self->{ParamObject}->GetArray( Param => 'QueueID' ) ) {
+        @CustomQueueIDs = $Self->{ParamObject}->GetArray( Param => 'QueueID' );
     }
     elsif ( $Param{UserData}->{UserID} && !defined $CustomQueueIDs[0] ) {
-        @CustomQueueIDs = $QueueObject->GetAllCustomQueues(
+        @CustomQueueIDs = $Self->{QueueObject}->GetAllCustomQueues(
             UserID => $Param{UserData}->{UserID}
         );
     }
@@ -66,7 +70,7 @@ sub Param {
         @Params,
         {
             %Param,
-            Option => $Kernel::OM->Get('Kernel::Output::HTML::Layout')->AgentQueueListOption(
+            Option => $Self->{LayoutObject}->AgentQueueListOption(
                 Data               => \%QueueData,
                 Size               => 10,
                 Name               => 'QueueID',
@@ -86,47 +90,40 @@ sub Run {
     my ( $Self, %Param ) = @_;
 
     # delete old custom queues
-    $Kernel::OM->Get('Kernel::System::DB')->Do(
-        SQL => "
-            DELETE FROM personal_queues
-            WHERE user_id = ?",
-        Bind => [ \$Param{UserData}->{UserID} ],
+    $Self->{DBObject}->Do(
+        SQL => "DELETE FROM personal_queues WHERE user_id = $Param{UserData}->{UserID}",
     );
 
     # get ro groups of agent
-    my %GroupMember = $Kernel::OM->Get('Kernel::System::Group')->GroupMemberList(
+    my %GroupMember = $Self->{GroupObject}->GroupMemberList(
         UserID => $Param{UserData}->{UserID},
         Type   => 'ro',
         Result => 'HASH',
     );
 
     # add new custom queues
-    my $QueueObject = $Kernel::OM->Get('Kernel::System::Queue');
-    for my $Key ( sort keys %{ $Param{GetParam} } ) {
+    for my $Key ( keys %{ $Param{GetParam} } ) {
         my @Array = @{ $Param{GetParam}->{$Key} };
         for my $ID (@Array) {
 
             # get group of queue
-            my %Queue = $QueueObject->QueueGet( ID => $ID );
+            my %Queue = $Self->{QueueObject}->QueueGet( ID => $ID );
 
             # check permissions
             if ( $GroupMember{ $Queue{GroupID} } ) {
 
+                # db quote
+                $ID = $Self->{DBObject}->Quote($ID);
                 $Self->{DBObject}->Do(
-                    SQL => "
-                        INSERT INTO personal_queues (queue_id, user_id)
-                        VALUES (?, ?)",
-                    Bind => [ \$ID, \$Param{UserData}->{UserID} ]
+                    SQL => "INSERT INTO personal_queues (queue_id, user_id) "
+                        . " VALUES ($ID, $Param{UserData}->{UserID})",
                 );
             }
         }
     }
 
     my $CacheKey = 'GetAllCustomQueues::' . $Param{UserData}->{UserID};
-    $Kernel::OM->Get('Kernel::System::Cache')->Delete(
-        Type => 'Queue',
-        Key  => $CacheKey,
-    );
+    $Self->{CacheInternalObject}->Delete( Key => $CacheKey );
 
     $Self->{Message} = 'Preferences updated successfully!';
     return 1;
