@@ -2,7 +2,7 @@
 # Kernel/System/CustomerUser/DB.pm - some customer user functions
 # Copyright (C) 2001-2012 OTRS AG, http://otrs.org/
 # --
-# $Id: DB.pm,v 1.88 2012/03/21 11:52:35 mh Exp $
+# $Id: DB.pm,v 1.88.2.1 2012/05/16 09:42:33 mg Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -21,7 +21,7 @@ use Kernel::System::Valid;
 use Kernel::System::Cache;
 
 use vars qw(@ISA $VERSION);
-$VERSION = qw($Revision: 1.88 $) [1];
+$VERSION = qw($Revision: 1.88.2.1 $) [1];
 
 sub new {
     my ( $Type, %Param ) = @_;
@@ -239,9 +239,12 @@ sub CustomerSearch {
             );
             return;
         }
+
+        my $Search = $Self->{DBObject}->QueryStringEscape( QueryString => $Param{Search} );
+
         $SQL .= $Self->{DBObject}->QueryCondition(
             Key          => $Self->{CustomerUserMap}->{CustomerUserSearchFields},
-            Value        => $Param{Search},
+            Value        => $Search,
             SearchPrefix => $Self->{SearchPrefix},
             SearchSuffix => $Self->{SearchSuffix},
         ) . ' ';
